@@ -54,6 +54,16 @@ class Pong(amp.Command):
 class Pid(amp.Command):
     response = [('pid', amp.Integer())]
 
+class Reactor(amp.Command):
+    response = [('classname', amp.String())]
+
+class NoResponse(amp.Command):
+    arguments = [('arg', amp.String())]
+    requiresAnswer = False
+
+class GetResponse(amp.Command):
+    response = [("response", amp.String())]
+
 class Child(child.AMPChild):
     def ping(self, data):
         return self.callRemote(Pong, data=data)
@@ -65,6 +75,23 @@ class PidChild(child.AMPChild):
         return {'pid': os.getpid()}
     Pid.responder(pid)
 
+class NoResponseChild(child.AMPChild):
+    _set = False
+    def noresponse(self, arg):
+        self._set = arg
+        return {}
+    NoResponse.responder(noresponse)
+    
+    def getresponse(self):
+        return {"response": self._set}
+    GetResponse.responder(getresponse)
+
+class ReactorChild(child.AMPChild):
+    def reactor(self):
+        from twisted.internet import reactor
+        return {'classname': reactor.__class__.__name__}
+    Reactor.responder(reactor)
+
 class First(amp.Command):
     arguments = [('data', amp.String())]
     response = [('response', amp.String())]
@@ -553,6 +580,54 @@ class TestProcessPool(unittest.TestCase):
             ).addCallback(_checks2
             ).addCallback(_checks2
             ).addCallback(finish)        
+    
+    def test_changeChildrenReactor(self):
+        """
+        Test that by passing the correct argument children change their
+        reactor type.
+        """
+        MAX = 1
+        MIN = 1
+        FIRST = "select"
+        SECOND = "poll"
+        
+        def checkDefault():
+            pp = pool.ProcessPool(ReactorChild, min=MIN, max=MAX, childReactor=FIRST)
+            pp.start()
+            return pp.doWork(Reactor
+                ).addCallback(self.assertEquals, {'classname': "SelectReactor"}
+                ).addCallback(lambda _: pp.stop())
+            
+        def checkPool(_):
+            pp = pool.ProcessPool(ReactorChild, min=MIN, max=MAX, childReactor=SECOND)
+            pp.start()
+            return pp.doWork(Reactor
+                ).addCallback(self.assertEquals, {'classname': "PollReactor"}
+                ).addCallback(lambda _: pp.stop())
+            
+        return checkDefault(
+            ).addCallback(checkPool)
+    try:
+        from select import poll
+    except ImportError:
+        test_changeChildrenReactor.skip = "This architecture doesn't support select.poll, I can't run this test"
 
+    def test_commandsWithoutResponse(self):
+        """
+        Test that if we send a command without a required answer we
+        actually don't have any problems.
+        """
+        DATA = "hello"
+        pp = pool.ProcessPool(NoResponseChild, min=1, max=1)
 
+        def _check(_):
+            return pp.doWork(GetResponse
+                ).addCallback(self.assertEquals, {"response": DATA})
+        
+        def _work(_):
+            return pp.doWork(NoResponse, arg=DATA)
 
+        return pp.start(
+            ).addCallback(_work
+            ).addCallback(_check
+            ).addCallback(lambda _: pp.stop())
